import { executeQuery } from '../Connection/QueriesExecutor.js'
import BaseInfoController from '../Controllers/BaseInfoController.js'

const getCards = async function (body) {
    const { CDCLIENTE, CDCONSUMIDOR } = body
    const result = await executeQuery({sql: 'GET_CREDIT_CARD', 
        binds: { CDCLIENTE, CDCONSUMIDOR },
        rawReturn: true
    })
    return result
}

const getCardStatus = async function (CDCONSUMIDOR, consDetails) {
    const { CDCLIENTE } = consDetails
    const result = await executeQuery({sql: 'GET_CARD_STATUS',
        binds: { CDCONSUMIDOR, CDCLIENTE },
        rawReturn: true
    })

    return result
}

const toggleCardStatus = async function (IDSITCONSUMI, CDCONSUMIDOR, consDetails) {
    const { CDCLIENTE } = consDetails
    
    // em espera - ao clicar em bloquear o IDSITCONSUMI = 2 faz o sistema parar

    const result = await executeQuery({sql: 'TOGGLE_CARD_BLOCK',
        binds: { IDSITCONSUMI, CDCLIENTE, CDCONSUMIDOR },
        rawReturn: true
    })
    
    return result
}

const getPaymentPlatform = async function (CDFILIAL) {
    let result = await executeQuery({sql: 'GET_PAYMENT_PLATFORM_BY_FILIAL',
        binds: { CDFILIAL },
        rawReturn: true
    })
    if (!result || result[0].IDPLATAFORMAPAG === null) {
        result = await executeQuery({sql: 'GET_PAYMENT_PLATFORM',
            rawReturn: true
        })
    }
    return (result && result[0]) || null
}

const getOnlinePaymentInfo = async function (CDFILIAL) {
    let result = await executeQuery({sql: 'GET_ONLINE_PAYMENT_INFO_BY_FILIAL',
        binds: { CDFILIAL },
        rawReturn: true
    })

    if (!result || result[0].IDLOJAESITEF === null || result[0].CDLOJAESITEF === null) {
        result = await executeQuery({sql: 'GET_ONLINE_PAYMENT_INFO',
            rawReturn: true
        })
    }
    return (result && result[0]) || null
}

const storeCreditCardToken = async function (creditCard) {
    const result = await executeQuery({sql: 'STORE_CREDIT_CARD_TOKEN',
        binds: creditCard,
        rawReturn: true
    })

    return result
}

const deleteCreditCard = async function (CDCARTCRED) {

    const result = await executeQuery({sql: 'DELETE_CREDIT_CARD',
        binds: { CDCARTCRED },
        rawReturn: true
    })
    return result
}

const setAllCreditCardsToFlagO = async function (CDCLIENTE, CDCONSUMIDOR) {
    const result = await executeQuery({sql: 'SET_ALL_CREDIT_CARDS_TO_FLAG_O',
        binds: { CDCLIENTE, CDCONSUMIDOR },
        rawReturn: true
    })

    return result
}

const setCreditCardToFlagP = async function (CDCARTCRED) {
    const result = await executeQuery({sql: 'SET_CREDIT_CARD_TO_FLAG_P',
        binds: { CDCARTCRED },
        rawReturn: true
    })

    return result
}

const getNrseqbandeira = async function (flag) {
    const IDESITEF = flag
    const result = await executeQuery({sql: 'GET_NRSEQBANDEIRA',
        binds: { IDESITEF },
        rawReturn: true
    })

    return result && result[0]
}

const getNewCardCode = async function () {
    const baseInfo = await BaseInfoController.getBaseInfo()
    const NRORG = baseInfo[0].NRORG.toString()
    let binds = {
        NRORGNOVOCODIGO: NRORG,
        NOMETABELA: 'CARTCREDCONS'
    }
    const result = await executeQuery({
        rawReturn: true,
        binds,
        newCode: true 
    })

    return result
}

const checkDuplicatedCreditCardToken = async function (token) {
    
    // em espera - ao clicar em bloquear o IDSITCONSUMI = 2 faz o sistema parar

    const result = await executeQuery({sql: 'CHECK_DUPLICATED_CREDIT_CARD_TOKEN',
        binds: { DSTOKEN: token },
        rawReturn: true
    })
    
    return result && result[0] || null
}

export default { 
    getCards,
    getCardStatus,
    toggleCardStatus,
    getPaymentPlatform,
    getOnlinePaymentInfo,
    storeCreditCardToken,
    deleteCreditCard,
    getNrseqbandeira,
    getNewCardCode,
    checkDuplicatedCreditCardToken,
    setAllCreditCardsToFlagO,
    setCreditCardToFlagP
}
