const { defineConfig } = require('@vue/cli-service')
const dotenv = require('dotenv')
const { DefinePlugin } = require('webpack')
const fs = require('fs')

module.exports = defineConfig(() => {
    const mode = process.argv[process.argv.indexOf('--rEnvironment') + 1]
    const envFilePath = {
        dev: 'dev.env',
        prod: 'prod.env',
        connect: 'connect.env'
    }

    dotenv.config({ path: './src/config/prod.env' })
    const overrideEnv = dotenv.parse(fs.readFileSync('./src/config/' + envFilePath[mode]))

    const mergedEnv = { ...process.env, ...overrideEnv }

    const stringLiteralsEnv = {}
    for (const key in mergedEnv) {
        stringLiteralsEnv[key] = JSON.stringify(mergedEnv[key])
    }
    // eslint-disable-next-line no-labels
    return {
        publicPath: process.env.NODE_ENV === 'development' ? '/' : './',
        outputDir: 'dist/static',
        configureWebpack: {
            plugins: [
                new DefinePlugin({ 'process.env': stringLiteralsEnv })
            ]
        },
        transpileDependencies: true,
        pwa: {
            name: 'Nocash',
            display: 'standalone',
            themeColor: '#0098b7',
            msTileColor: '#0098b7',
            manifestOptions: {
                name: 'Nocash',
                short_name: 'Nocash',
                start_url: '.',
                background_color: '#0098b7',
                theme_color: '#0098b7',
                icons: [
                    {
                        src: './img/icons/android-chrome-192x192.png',
                        sizes: '192x192',
                        type: 'image/png'
                    },
                    {
                        src: './img/icons/android-chrome-512x512.png',
                        sizes: '512x512',
                        type: 'image/png'
                    },
                    {
                        src: './img/icons/android-chrome-maskable-192x192.png',
                        sizes: '192x192',
                        type: 'image/png',
                        purpose: 'maskable'
                    },
                    {
                        src: './img/icons/android-chrome-maskable-512x512.png',
                        sizes: '512x512',
                        type: 'image/png',
                        purpose: 'maskable'
                    }
                ]
            },
            iconPaths: {
                faviconSVG: './img/icons/safari-pinned-tab.svg',
                favicon32: './img/icons/favicon-32x32.png',
                favicon16: './img/icons/favicon-16x16.png',
                appleTouchIcon: './img/icons/apple-touch-icon.png',
                maskIcon: './img/icons/android-chrome-maskable-512x512.png',
                msTileImage: './img/icons/mstile-150x150.png'
            }
        }
    }
})
// const { defineConfig } = require('@vue/cli-service')
// module.exports = defineConfig({
//     transpileDependencies: true
// })
